@@ -1,21 +1,3 @@
-# """
-# A feature store client. This module exposes an API for interacting with feature stores in Bytehub.
-# It hides complexity and provides utility methods such as:
-#     - `configure()`
-#     - `create_feature()`
-#     - `get_feature()`.
-#     #- `project_featurestore()`.
-#     #- `get_featuregroup()`.
-#     - `get_timeseries()`.
-#     #- `sql()`
-#     #- `insert_into_featuregroup()`
-#     #- `get_featurestore_metadata()`
-#     #- `get_project_featurestores()`
-#     #- `get_featuregroups()`
-#     #- `get_training_datasets()`
-# """
-
-
 import os
 import itertools
 import operator
@@ -33,6 +15,7 @@ import types
 import dill
 import base64
 from io import BytesIO
+from bytehub.exceptions import *
 
 
 class FeatureStore():
@@ -58,7 +41,6 @@ class FeatureStore():
     >>> fs = bh.FeatureStore()
     """
 
-
     def __init__(self, endpoint, client_id=None, client_secret=None):
         # Save the endpoint
         self.endpoint = endpoint
@@ -66,7 +48,7 @@ class FeatureStore():
             self.endpoint += '/'
         # Get the Oauth2 URLs
         response = requests.get(self.endpoint + 'auth')
-        response.raise_for_status()
+        self._check_response(response)
         self.urls = response.json()
 
         # Decide with authentication method to use
@@ -95,6 +77,10 @@ class FeatureStore():
                 self.urls['token_url'], code=code_response, include_client_id=True
             )
         self.tokens = tokens
+        # Other settings
+        self.use_parquet = True
+        self.compression = 'gzip'
+        self.user_info = self.user()
 
     def _check_tokens(self):
         # Check that token hasn't expired
@@ -127,6 +113,17 @@ class FeatureStore():
             'Authorization': self.tokens['access_token'],
         }
     
+    def _check_response(self, response):
+        try:
+            response.raise_for_status()
+        except requests.exceptions.RequestException as e:
+            try:
+                payload = response.json()
+                message = payload.get('message', payload.get('Message', ''))
+            except requests.exceptions.RequestException:
+                message = response.text
+            raise FeatureStoreException(message)
+
     def _decode_function(self, encoded_function):
         if isinstance(encoded_function, str):
             encoded_function = encoded_function.encode('utf-8')
@@ -142,7 +139,23 @@ class FeatureStore():
     def _encode_function(self, func):
         return base64.b64encode(dill.dumps(func)).decode('utf-8')
 
-    def list_features(self, feature=None, regex=None, metadata=False):
+    def _full_name(self, name):
+        """Adds default organisation to names, where not already specified."""
+        if isinstance(name, list):
+            return [self._full_name(n) for n in name]
+        default_org = self.user_info['organisation'].get('name', 'bytehub')
+        return name if '/' in name else default_org + '/' + name
+
+    def user(self):
+        url = self.endpoint + 'current_user'
+
+        response = requests.get(
+            url, headers=self._api_headers())
+        self._check_response(response)
+
+        return response.json()
+
+    def list_features(self, feature=None, regex=None, meta=False):
         """List features in feature store.
 
         Parameters
@@ -151,13 +164,13 @@ class FeatureStore():
             Only return these features.
         regex : str, optional
             Regular expression to filter feature names.
-        metadata : bool, default False
+        meta : bool, default False
             Return metadata with features.
 
         Returns
         -------
         list[str] or pd.DataFrame
-            A list of features or dataframe of features and metadata.
+            A list of features or dataframe of features and meta.
 
         Examples
         --------
@@ -165,20 +178,20 @@ class FeatureStore():
 
         ['feature1', 'feature2', 'feature3']
 
-        >>> fs.list_features(regex='weather', metadata=True)
-            name            metadata
-        ------------------------------------------
-        0   weather.actual  {'source': 'NOAA GFS'}
+        >>> fs.list_features(regex='weather', meta=True)
+            full_name                meta
+        --------------------------------------------------
+        0   bytehub/weather.actual  {'source': 'NOAA GFS'}
         """
 
-        assert type(metadata) is bool, "metadata is type, bool."
+        assert type(meta) is bool, "meta is type, bool."
         assert regex is None or isinstance(
             regex, str), "Expecting regex of type, str."
 
         df = self.get_feature_data_frame(feature=feature, regex=regex)
 
-        if metadata:
-            return df[['name', 'metadata']]
+        if meta:
+            return df[['name', 'meta']]
         else:
             return df.name.tolist()
 
@@ -200,15 +213,15 @@ class FeatureStore():
         >>> fs.feature_exists(['feature1', 'nonsense'])
         [True, False]
         """
-
+        
         names = self.list_features(feature=feature)
         if isinstance(feature, list):
-            return [f in names for f in feature]
+            return [self._full_name(f) in names for f in feature]
         else:
-            return feature in names
+            return self._full_name(feature) in names
 
     def get_feature_data_frame(self, feature=None, regex=None):
-        """Get a dataframe of feature metadata.
+        """Get a dataframe of feature meta.
 
         Parameters
         ----------
@@ -220,15 +233,15 @@ class FeatureStore():
         Returns
         -------
         pd.DataFrame
-            A dataframe containing feature metadata
+            A dataframe containing feature meta
 
         Examples
         --------
         >>> fs.get_feature_data_frame(['feature1', 'feature2'])
-            id                                      name            metadata
-        ----------------------------------------------------------------------------
-        0   0341bacc-e161-11ea-a042-0a53e92ebe18    feature1        {'source': NULL}
-        1   193177cc-e158-11ea-a042-0a53e92ebe18    feature2        {'source': NULL}
+            id                                      name                    meta
+        ------------------------------------------------------------------------------------
+        0   0341bacc-e161-11ea-a042-0a53e92ebe18    bytehub/feature1        {'source': NULL}
+        1   193177cc-e158-11ea-a042-0a53e92ebe18    bytehub/feature2        {'source': NULL}
         """
 
         params = {}
@@ -246,13 +259,13 @@ class FeatureStore():
 
         response = requests.get(
             url, params=params, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         result = response.json()
-        
+
         df = pd.DataFrame({'id': [r['id'] for r in result],
-                           'name': [r['name'] for r in result],
-                           'metadata': [r['metadata'] for r in result]})
+                           'name': [r['full_name'] for r in result],
+                           'meta': [r['meta'] for r in result]})
 
         return df
 
@@ -278,19 +291,20 @@ class FeatureStore():
 
         df = self.get_feature_data_frame(feature=feature)
         if isinstance(feature, str):
-            assert feature in df.name.tolist(), f'The feature(s), {feature}, is non-existent.'
-            return df[df.name == feature]['id'].iloc[0]
+            assert self._full_name(feature) in df.name.tolist(
+            ), f'The feature(s), {feature}, is non-existent.'
+            return df[df.name == self._full_name(feature)]['id'].iloc[0]
         else:
             assert len(feature) == len(
                 df), 'One or more features are non-existent.'
             result = [
-                df[df.name == f]['id'].iloc[0]
+                df[df.name == self._full_name(f)]['id'].iloc[0]
                 for f in feature
             ]
             return result
 
-    def get_feature_metadata(self, feature):
-        """Get the metadata for feature(s).
+    def get_feature_meta(self, feature):
+        """Get the meta for feature(s).
 
         Parameters
         ----------
@@ -300,12 +314,12 @@ class FeatureStore():
         Returns
         -------
         pd.DataFrame
-            A dataframe of metadata for feature(s).
+            A dataframe of meta for feature(s).
 
         Examples
         --------
-        >>> fs.get_feature_metadata(['feature1', 'feature2'])
-            name            metadata
+        >>> fs.get_feature_meta(['feature1', 'feature2'])
+            name            meta
         ------------------------------------
         0   feature1        {'source': NULL}
         1   feature2        {'source': NULL}
@@ -313,7 +327,7 @@ class FeatureStore():
 
         df = self.get_feature_data_frame(feature)
 
-        return df[['name', 'metadata']]
+        return df[['name', 'meta']]
 
     def get_first(self, feature):
         """Gets first entry from feature in feature store per entity.
@@ -344,7 +358,7 @@ class FeatureStore():
 
         url = self.endpoint + f'timeseries/{feature_id}/first'
         response = requests.get(url, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         df = pd.DataFrame(response.json())
 
@@ -380,7 +394,7 @@ class FeatureStore():
 
         url = self.endpoint + f'timeseries/{feature_id}/last'
         response = requests.get(url, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         df = pd.DataFrame(response.json())
 
@@ -414,7 +428,7 @@ class FeatureStore():
 
         url = self.endpoint + f'timeseries/{feature_id}/freq'
         response = requests.get(url, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         return response.json()['freq']
 
@@ -473,18 +487,22 @@ class FeatureStore():
             'freq': freq,
             'time_travel': time_travel,
             'entity': ','.join(entity) if entity else None,
-            'format': 'parquet'
+            'format': 'parquet' if self.use_parquet else 'json'
         }
         headers = self._api_headers()
         # Set this header to allow response to be returned as Parquet
-        headers['Accept'] = 'application/octet-stream'
+        if self.use_parquet:
+            headers['Accept'] = 'application/octet-stream'
         response = requests.get(
             url, params=params, headers=headers)
-        response.raise_for_status()
+        self._check_response(response)
 
-        # Load parquet response
-        buffer = BytesIO(response.content)
-        df = pd.read_parquet(buffer)
+        if self.use_parquet:
+            # Load parquet response
+            buffer = BytesIO(response.content)
+            df = pd.read_parquet(buffer)
+        else:
+            df = pd.DataFrame(response.json())
         if df.empty:
             return pd.DataFrame(
                 {
@@ -527,28 +545,38 @@ class FeatureStore():
         if 'created_time' in df.columns:
             assert is_datetime(
                 df.created_time), 'In DataFrame, created_time column must be a datetime'
-        
+
         feature_id = self.get_feature_id(feature)
         url = self.endpoint + f'timeseries/{feature_id}'
 
         headers = self._api_headers()
 
-        if len(df) > 10:
+        if self.use_parquet:
             # Send the payload as parquet
             buffer = BytesIO()
-            df.to_parquet(buffer, index=False, allow_truncated_timestamps=True, compression='gzip')
+            df.to_parquet(
+                buffer, index=False, allow_truncated_timestamps=True, compression=self.compression)
             buffer.seek(0)
             headers['Content-Type'] = 'application/octet-stream'
             response = requests.post(
                 url, data=buffer.read(), headers=headers
             )
         else:
-            # Convert payload to JSON
+            # Send payload JSON
             payload = json.loads(df.to_json(orient='records'))
-            response = requests.post(
-                url, json=payload, headers=headers
-            )
-        response.raise_for_status()
+            if self.compression == 'gzip':
+                headers['Content-Type'] = 'application/json'
+                headers['Content-Encoding'] = 'gzip'
+                payload = gzip.compress(json.dumps(payload).encode('utf-8'))
+                response = requests.post(
+                    url, data=payload, headers=headers
+                )
+            else:
+                response = requests.post(
+                    url, json=payload, headers=headers
+                )
+
+        self._check_response(response)
 
     def create_feature(self, name, **kwargs):
         """Adds a feature to the feature store.
@@ -559,7 +587,7 @@ class FeatureStore():
             Feature name.
 
         kwargs : dict, optional
-            Data to be added to metadata.
+            Data to be added to meta.
 
         Examples
         --------
@@ -567,17 +595,18 @@ class FeatureStore():
         """
 
         assert isinstance(name, str), 'Feature names should be type, str.'
-        assert bool(re.match(r'^[a-zA-Z0-9\./#_-]+$', name)), 'Feature name must only contain alphanumeric .#_-'
+        assert bool(re.match(r'^[a-zA-Z0-9\./#_-]+$', name)
+                    ), 'Feature name must only contain alphanumeric .#_-'
         assert not self.feature_exists(name), 'Feature already exists.'
 
         payload = {
             'name': name,
-            'metadata': kwargs
+            'meta': kwargs
         }
         url = self.endpoint + f'feature'
         response = requests.post(
             url, json=payload, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         data = response.json()
 
@@ -596,7 +625,7 @@ class FeatureStore():
             Optional dictionary of kwargs to be passed to the transform
 
         kwargs : dict, optional
-            Data to be added to metadata.
+            Data to be added to meta.
 
         Examples
         --------
@@ -604,29 +633,35 @@ class FeatureStore():
         """
 
         assert isinstance(name, str), 'Feature names should be type, str.'
-        assert bool(re.match(r'^[a-zA-Z0-9\./#_-]+$', name)), 'Feature name must only contain alphanumeric .#_-'
+        assert bool(re.match(r'^[a-zA-Z0-9\./#_-]+$', name)
+                    ), 'Feature name must only contain alphanumeric .#_-'
         assert not self.feature_exists(name), 'Feature already exists.'
-        assert self.transform_exists(transform), 'Transform must exist in the feature store'
-        assert isinstance(params, dict), 'params should be a dictionary of name: value pairs'
+        assert self.transform_exists(
+            transform), 'Transform must exist in the feature store'
+        assert isinstance(
+            params, dict), 'params should be a dictionary of name: value pairs'
         if isinstance(derived_from, str):
             derived_from = [derived_from]
         elif isinstance(derived_from, list):
-            assert len(derived_from) == 1, 'Multiple derived_from features not implemented yet'
-            assert self.feature_exists(derived_from[0]), f'Feature {derived_from} does not exist'
-        assert isinstance(derived_from, str) or isinstance(derived_from, list), 'derived_from must be string or list of strings'
+            assert len(
+                derived_from) == 1, 'Multiple derived_from features not implemented yet'
+            assert self.feature_exists(
+                derived_from[0]), f'Feature {derived_from} does not exist'
+        assert isinstance(derived_from, str) or isinstance(
+            derived_from, list), 'derived_from must be string or list of strings'
 
         payload = {
             'name': name,
-            'transform': self.get_transform_id(transform),
+            'transform_id': self.get_transform_id(transform),
             'compute_type': 'virtual',
-            'derived_from': [self.get_feature_id(f) for f in derived_from],
+            'calculated_from_ids': [self.get_feature_id(f) for f in derived_from],
             'params': params,
-            'metadata': kwargs
+            'meta': kwargs
         }
         url = self.endpoint + f'feature'
         response = requests.post(
             url, json=payload, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         data = response.json()
 
@@ -649,7 +684,7 @@ class FeatureStore():
         feature_id = self.get_feature_id(name)
         url = self.endpoint + f'feature/{feature_id}'
         response = requests.delete(url, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
     def update_feature(self, name, **kwargs):
         """Update a feature in the feature store.
@@ -660,7 +695,7 @@ class FeatureStore():
             Feature name.
 
         kwargs : dict, optional
-            Data to be added to metadata.
+            Data to be added to meta.
 
         Examples
         --------
@@ -672,17 +707,17 @@ class FeatureStore():
 
         payload = {
             'name': name,
-            'metadata': kwargs
+            'meta': kwargs
         }
         feature_id = self.get_feature_id(name)
         url = self.endpoint + f'feature/{feature_id}'
         response = requests.patch(
             url, json=payload, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         data = response.json()
 
-    def list_transforms(self, transform=None, regex=None, metadata=False):
+    def list_transforms(self, transform=None, regex=None, meta=False):
         """List transforms in feature store.
 
         Parameters
@@ -691,13 +726,13 @@ class FeatureStore():
             Only return these transforms.
         regex : str, optional
             Regular expression to filter transform names.
-        metadata : bool, default False
+        meta : bool, default False
             Return metadata with transform.
 
         Returns
         -------
         list[str] or pd.DataFrame
-            A list of transforms or dataframe of transforms and metadata.
+            A list of transforms or dataframe of transforms and meta.
 
         Examples
         --------
@@ -705,20 +740,20 @@ class FeatureStore():
 
         ['transform1', 'transform2', 'transform3']
 
-        >>> fs.list_transforms(regex='extract.', metadata=True)
-            name            metadata
+        >>> fs.list_transforms(regex='extract.', meta=True)
+            name            meta
         ------------------------------------------
         0   extract-keys  {'source': 'NOAA GFS'}
         """
 
-        assert type(metadata) is bool, "metadata is type, bool."
+        assert type(meta) is bool, "meta is type, bool."
         assert regex is None or isinstance(
             regex, str), "Expecting regex of type, str."
 
         df = self.get_transform_data_frame(transform=transform, regex=regex)
 
-        if metadata:
-            return df[['name', 'description', 'transform_type', 'metadata']]
+        if meta:
+            return df[['name', 'description', 'transform_type', 'meta']]
         else:
             return df.name.tolist()
 
@@ -743,12 +778,12 @@ class FeatureStore():
 
         names = self.list_transforms(transform=transform)
         if isinstance(transform, list):
-            return [t in names for t in transform]
+            return [self._full_name(t) in names for t in transform]
         else:
-            return transform in names
-    
+            return self._full_name(transform) in names
+
     def get_transform_data_frame(self, transform=None, regex=None):
-        """Get a dataframe of transform metadata.
+        """Get a dataframe of transform meta.
 
         Parameters
         ----------
@@ -765,7 +800,7 @@ class FeatureStore():
         Examples
         --------
         >>> fs.get_transform_data_frame(['transform1', 'transform2'])
-            id                                      name         description      transform_type   metadata
+            id                                      name         description      transform_type   meta
         ---------------------------------------------------------------------------------------------------
         0   0341bacc-e161-11ea-a042-0a53e92ebe18    transform1   Transform 1      simple           {}
         1   193177cc-e158-11ea-a042-0a53e92ebe18    transform2   Transform 2      dataframe        {}
@@ -785,15 +820,15 @@ class FeatureStore():
         url = self.endpoint + 'transform'
         response = requests.get(
             url, params=params, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         result = response.json()
 
         df = pd.DataFrame({'id': [r['id'] for r in result],
-                           'name': [r['name'] for r in result],
+                           'name': [r['full_name'] for r in result],
                            'description': [r['description'] for r in result],
                            'transform_type': [r['transform_type'] for r in result],
-                           'metadata': [r['metadata'] for r in result]})
+                           'meta': [r['meta'] for r in result]})
 
         return df
 
@@ -819,13 +854,14 @@ class FeatureStore():
 
         df = self.get_transform_data_frame(transform=transform)
         if isinstance(transform, str):
-            assert transform in df.name.tolist(), f'The transform(s), {transform}, is non-existent.'
-            return df[df.name == transform]['id'].iloc[0]
+            assert self._full_name(transform) in df.name.tolist(
+            ), f'The transform(s), {transform}, is non-existent.'
+            return df[df.name == self._full_name(transform)]['id'].iloc[0]
         else:
             assert len(transform) == len(
                 df), 'One or more transforms are non-existent.'
             result = [
-                df[df.name == t]['id'].iloc[0]
+                df[df.name == self._full_name(t)]['id'].iloc[0]
                 for t in transform
             ]
             return result
@@ -850,14 +886,14 @@ class FeatureStore():
 
         if isinstance(transform, list):
             return [self.get_transform_func(t) for t in transform]
-        
+
         transform_id = self.get_transform_id(transform)
 
         url = self.endpoint + f'transform/{transform_id}'
         response = requests.get(
             url, headers=self._api_headers()
         )
-        response.raise_for_status()
+        self._check_response(response)
         result = response.json()
 
         if not result.get('code'):
@@ -880,7 +916,7 @@ class FeatureStore():
             A dictionary of {"name": default_value} pairs, which may be passed to the transform function.
 
         kwargs : dict, optional
-            Data to be added to metadata.
+            Data to be added to meta.
 
         Examples
         --------
@@ -888,9 +924,11 @@ class FeatureStore():
         """
 
         assert isinstance(name, str), 'Transform names should be type, str.'
-        assert bool(re.match(r'^[a-zA-Z0-9\./#_-]+$', name)), 'Transform name must only contain alphanumeric .#_-'
+        assert bool(re.match(r'^[a-zA-Z0-9\./#_-]+$', name)
+                    ), 'Transform name must only contain alphanumeric .#_-'
         assert not self.transform_exists(name), 'Transform already exists.'
-        assert isinstance(func, types.FunctionType), 'A valid function must be provided'
+        assert isinstance(
+            func, types.FunctionType), 'A valid function must be provided'
 
         payload = {
             'name': name,
@@ -898,12 +936,12 @@ class FeatureStore():
             'transform_type': transform_type,
             'params': params,
             'code': self._encode_function(func),
-            'metadata': kwargs
+            'meta': kwargs
         }
         url = self.endpoint + f'transform'
         response = requests.post(
             url, json=payload, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         data = response.json()
 
@@ -926,7 +964,7 @@ class FeatureStore():
         transform_id = self.get_transform_id(name)
         url = self.endpoint + f'transform/{transform_id}'
         response = requests.delete(url, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
     def update_transform(self, name, func=None, transform_type=None, params=None, **kwargs):
         """Update a transform in the feature store.
@@ -943,7 +981,7 @@ class FeatureStore():
             A dictionary of {"name": default_value} pairs, which may be passed to the transform function.
 
         kwargs : dict, optional
-            Data to be added to metadata.
+            Data to be added to meta.
 
         Examples
         --------
@@ -955,23 +993,26 @@ class FeatureStore():
 
         payload = {
             'name': name,
-            'metadata': kwargs
+            'meta': kwargs
         }
         if func:
-            assert isinstance(func, types.FunctionType), 'A valid function must be provided'
+            assert isinstance(
+                func, types.FunctionType), 'A valid function must be provided'
             payload['code'] = self._encode_function(func)
             payload['description'] = func.__doc__
         if transform_type:
-            assert transorm_type.lower() in ['simple', 'dataframe'], 'Transform type must be simple or dataframe'
+            assert transorm_type.lower() in [
+                'simple', 'dataframe'], 'Transform type must be simple or dataframe'
             payload['transform_type'] = transform_type.lower()
         if params:
-            assert isinstance(params, dict), 'Params must be a dictionary of name/value pairs'
+            assert isinstance(
+                params, dict), 'Params must be a dictionary of name/value pairs'
             payload['params'] = params
         transform_id = self.get_transform_id(name)
         url = self.endpoint + f'transform/{transform_id}'
         response = requests.patch(
             url, json=payload, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         data = response.json()
 
@@ -984,7 +1025,7 @@ class FeatureStore():
             Feature group name.
 
         kwargs : dict, optional
-            Data to be added to metadata.
+            Data to be added to meta.
 
         Examples
         --------
@@ -996,26 +1037,25 @@ class FeatureStore():
         payload = {
             'name': name,
             'feature_ids': feature_ids,
-            'metadata': kwargs
+            'meta': kwargs
         }
         url = self.endpoint + f'feature_group'
         response = requests.post(
             url, json=payload, headers=self._api_headers())
-        response.raise_for_status()
+        self._check_response(response)
 
         data = response.json()
 
     def split(target, past, future, include_time, horizon, initial, period,
               offset, max_train_size, cutoffs):
-        """
-        Generates train, validate, test splits for forecasting
+        """Generates train, validate, test splits for forecasting
         models. The splits can be based on historical cutoff points, which user
         can input. If not provided, begins from (end - horizon) and works
         backwards, making cutoffs with a spacing of period until initial is
         reached.
 
-		Parameters
-		----------
+        Parameters
+        ----------
         target: dict
             Dict containing features and timeseries to include as target,
             e.g. {"feature1" : "timeseries1", "feature2" : "timeseries2"...}.
@@ -1036,14 +1076,14 @@ class FeatureStore():
             Boolean indicating whether to include "time", e.g. timeseries
             timestamps, in inputs.
 
-		horizon: pd.Timedelta, optional
+        horizon: pd.Timedelta, optional
             string with pd.Timedelta compatible style, e.g., '5 days',
-		    '3 hours', '10 seconds'. Lookahead period of intended forecasts.
+            '3 hours', '10 seconds'. Lookahead period of intended forecasts.
 
         initial: pd.Timedelta, optional
             string with pd.Timedelta compatible style. The first training
-    		period will include at least this much data. If not provided,
-    		3 * horizon is used.
+            period will include at least this much data. If not provided,
+            3 * horizon is used.
 
         period: pd.Timedelta, optional
             string with pd.Timedelta compatible style. Intend forecasts to be
@@ -1063,14 +1103,14 @@ class FeatureStore():
             list of pd.Timestamp specifying train set end timestamps.
             If not provided, they are generated as described above.
 
-		Yields
-		-------
-		train: np.array
+        Yields
+        -------
+        train: np.array
             train set.
         validation: np.array
             validation set.
         test: np.array
             test set.
 
-		"""
+                """
         pass
